# 🛰️ COnstellation Satellite siMulator for optIcal CommunicAtion (COSMICA)

[![PyPI](https://img.shields.io/pypi/v/cosmica)](https://pypi.org/project/cosmica/)
![PyPI - License](https://img.shields.io/pypi/l/cosmica)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cosmica)
[![Test Status](https://github.com/ut-issl/cosmica/actions/workflows/ci.yaml/badge.svg)](https://github.com/ut-issl/cosmica/actions)
[![codecov](https://codecov.io/gh/ut-issl/cosmica/graph/badge.svg?token=050KA0MEP8)](https://codecov.io/gh/ut-issl/cosmica)
[![uv](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/uv/main/assets/badge/v0.json)](https://github.com/astral-sh/uv)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

COSMICA is a Python package for simulating optical communication satellite constellations. It is modular and extensible so that users can conduct various optical communication satellite constellation analyses. See [COSMICA documentation](https://www.space.t.u-tokyo.ac.jp/cosmica/) for more details.

## Usage

### Examples

- See `examples` directory for how to use COSMICA in analyses.

## Getting started

### Prerequisites

- Python 3.12 or higher

### Installation

If you use pip, install COSMICA by running:

```bash
pip install cosmica
```

## Structure

The diagram below shows the structure of the simulator. Each green box is a Python submodule.

![COSMICA structure](docs/assets/cosmica_structure.drawio.svg)

## License

This project is licensed under either of the MIT license or the Apache License 2.0 at your option.
